@@ -558,6 +558,8 @@ class M1N1Proxy(Reloadable):
     P_SMP_STOP_SECONDARIES = 0x506
     P_SMP_CALL_EL1 = 0x507
     P_SMP_CALL_SYNC_EL1 = 0x508
+    P_SMP_CALL_EL0 = 0x509
+    P_SMP_CALL_SYNC_EL0 = 0x50a
 
     P_HEAPBLOCK_ALLOC = 0x600
     P_MALLOC = 0x601
@@ -970,6 +972,14 @@ class M1N1Proxy(Reloadable):
         if len(args) > 3:
             raise ValueError("Too many arguments")
         return self.request(self.P_SMP_CALL_SYNC_EL1, cpu, addr, *args)
+    def smp_call_el0(self, cpu, addr, *args):
+        if len(args) > 3:
+            raise ValueError("Too many arguments")
+        self.request(self.P_SMP_CALL_EL0, cpu, addr, *args)
+    def smp_call_sync_el0(self, cpu, addr, *args):
+        if len(args) > 3:
+            raise ValueError("Too many arguments")
+        return self.request(self.P_SMP_CALL_SYNC_EL0, cpu, addr, *args)
 
     def heapblock_alloc(self, size):
         return self.request(self.P_HEAPBLOCK_ALLOC, size)
