@@ -26,6 +26,8 @@
 #define EARLY_UART_BASE 0x39b200000
 #elif TARGET == T8112
 #define EARLY_UART_BASE 0x235200000
+#elif TARGET == T6034 || TARGET == T6031
+#define EARLY_UART_BASE 0x391200000
 #endif
 
 #endif
